var searchData=
[
  ['s',['s',['../structplplot_1_1__N10.html#a7d755bebc7591ce80e880e10557ebdd3',1,'plplot::_N10::s()'],['../structPLControlPt.html#a744d7c8dc9c116529cd00507cffb2b65',1,'PLControlPt::s()']]],
  ['s1',['s1',['../classplplot__str.html#a42cd86889f700ffa06ecd3d91f5eddc8',1,'plplot_str']]],
  ['s2',['s2',['../classplplot__str.html#aef70b13708ef0fac3f661bf5bbe4cd1c',1,'plplot_str']]],
  ['s3',['s3',['../classplplot__str.html#aac08fceeef2b73bf4663c3eb6465a078',1,'plplot_str']]],
  ['s4',['s4',['../classplplot__str.html#a8899e0f28029a88ac0f23a3375967088',1,'plplot_str']]],
  ['s5',['s5',['../classplplot__str.html#ac31073c712b9653f5cd86dff484fc3ec',1,'plplot_str']]],
  ['s6',['s6',['../classplplot__str.html#ae969c0964823775d94d397f575fcdd33',1,'plplot_str']]],
  ['s7',['s7',['../classplplot__str.html#a96934ad53ec7b7780b303d42c2b5f138',1,'plplot_str']]],
  ['s8',['s8',['../classplplot__str.html#a83b38ce919ae6cf9a87fe1d466ea67e4',1,'plplot_str']]],
  ['s9',['s9',['../classplplot__str.html#a421d14df793b0769470e21b598ba1edf',1,'plplot_str']]],
  ['s_5fplf2ops_5fc',['s_plf2ops_c',['../plf2ops_8c.html#ac1c73dbbba3f29a97afa31ecee3e912d',1,'plf2ops.c']]],
  ['s_5fplf2ops_5fgrid_5fc',['s_plf2ops_grid_c',['../plf2ops_8c.html#a13cbd4216f32a6ddb19d3ae3dadaeb59',1,'plf2ops.c']]],
  ['s_5fplf2ops_5fgrid_5fcol_5fmajor',['s_plf2ops_grid_col_major',['../plf2ops_8c.html#a820fa4c7be448710c1aae54094641c13',1,'plf2ops.c']]],
  ['s_5fplf2ops_5fgrid_5frow_5fmajor',['s_plf2ops_grid_row_major',['../plf2ops_8c.html#a7036116675867b0559dfd5469cc88dc9',1,'plf2ops.c']]],
  ['savefnam',['SaveFnam',['../structPlFrame.html#a521677afa95435c0ac1b95c81d1717f4',1,'PlFrame::SaveFnam()'],['../structPlPlotter.html#a70bee92ad284277e100e2efc157fc580',1,'PlPlotter::SaveFnam()']]],
  ['scale',['scale',['../structSVG.html#a9447e7c85b2b17a779aaed3c3b4b8195',1,'SVG::scale()'],['../structPLStream.html#abfa28f6cc3addcf4409b19673a1a4aed',1,'PLStream::scale()'],['../structQSASConfigStruct.html#a91bdf8a49795a545ddb3e70738b645b4',1,'QSASConfigStruct::scale()']]],
  ['screen',['screen',['../structTkwDisplay.html#a0b074cbf56d320248729f0b98c783927',1,'TkwDisplay::screen()'],['../structXwDisplay.html#a86a7caa809b7c5684f911e785785118d',1,'XwDisplay::screen()']]],
  ['script',['script',['../tkMain_8c.html#a85ecf9241cb06e04c56f1f00e0c78da4',1,'tkMain.c']]],
  ['search_5fhandle',['search_handle',['../structDIR.html#ae25e6d75a05922f1526968118e27f4b8',1,'DIR']]],
  ['secinday',['SecInDay',['../qsastime_8c.html#a17aa99bfbb32cd993a393f08ba3432b9',1,'SecInDay():&#160;qsastime.c'],['../qsastime__extra_8c.html#a65d777a9b17303ce368d1fb26b23437a',1,'SecInDay():&#160;qsastime_extra.c']]],
  ['server_5fhost',['server_host',['../structPLStream.html#af209d2135121f622b8ab68c2121d0bc2',1,'PLStream']]],
  ['server_5fname',['server_name',['../structPLStream.html#ac76f61228b7fb7dde6ddd15babcfefb7',1,'PLStream']]],
  ['server_5fnokill',['server_nokill',['../structPLStream.html#a51329d69da74c79dcafcc4e74df0b147',1,'PLStream']]],
  ['server_5fport',['server_port',['../structPLStream.html#a53853e0fdb3024f22697d71cbf1a0bd6',1,'PLStream']]],
  ['set',['set',['../structplf2ops__t.html#a77ae2170fab46b2411fc67a3b6698d80',1,'plf2ops_t::set()'],['../structswig__lua__var__info.html#aea961df3cc15877e8354cb535bef2c1e',1,'swig_lua_var_info::set()']]],
  ['set_5fattr',['set_attr',['../structswig__globalvar.html#a494e3d5a5f1fb694b7738fdd1ffdd657',1,'swig_globalvar']]],
  ['set_5fbackground',['set_background',['../structPLCairo.html#a6b907acf00539f1553fd6ec99c95dba4',1,'PLCairo::set_background()'],['../cairo_8c.html#aa291e4e8c639d13aa0019c1da9136e29',1,'set_background():&#160;cairo.c']]],
  ['set_5fmethod',['set_method',['../structswig__octave__member.html#ad882b2fee1325724d716dba35c6bd75d',1,'swig_octave_member']]],
  ['setmethod',['setmethod',['../structswig__lua__attribute.html#a0b88e38d5417453e7718f7090b797b06',1,'swig_lua_attribute']]],
  ['setpre',['setpre',['../structPLStream.html#aba86231507a869b8be29afcdb7b42b05',1,'PLStream']]],
  ['sh_5fmax',['sh_max',['../plshade_8c.html#a1df1b9921dd61b9cfa61880c3bc5c6a7',1,'plshade.c']]],
  ['sh_5fmin',['sh_min',['../plshade_8c.html#a2398e9a0ea77b76e85ff7205866f4456',1,'plshade.c']]],
  ['shapecolor',['shapecolor',['../structcdImageStruct.html#a322da47adba06ee5e444faf14cac0f48',1,'cdImageStruct']]],
  ['shapehatch',['shapehatch',['../structcdImageStruct.html#acd1760d049041ac14c6828ae7a21701a',1,'cdImageStruct']]],
  ['shapestyle',['shapestyle',['../structcdImageStruct.html#a0786a428f234b886250565a929db1385',1,'cdImageStruct']]],
  ['sid',['sid',['../plstripc_8c.html#a53fe45b9d43c0da75fb377b484e44426',1,'plstripc.c']]],
  ['sign_5fdx',['sign_dx',['../namespacePlframe.html#a10542a807754bf1cbc956d8ca57b62c4',1,'Plframe']]],
  ['sign_5fdy',['sign_dy',['../namespacePlframe.html#afef6875b9cb349c664ae8618332b77f5',1,'Plframe']]],
  ['sigprec',['sigprec',['../plcont_8c.html#ac298436095ccaf5089d1ab27454c9276',1,'plcont.c']]],
  ['size',['size',['../structhashtable.html#ab62bd10297b090cfce7d728fd650e51d',1,'hashtable::size()'],['../struct__state.html#ac0af841d6c9a578ca508bef9ea2bed82',1,'_state::size()'],['../structplbuffer.html#a33962b4508b6f84beea781817118f681',1,'plbuffer::size()'],['../structswig__module__info.html#aaf8907cf8509ee0464af8c9dfd909042',1,'swig_module_info::size()'],['../structSwigPyPacked.html#aed2bfb8fb3c9f804c386215db63921cb',1,'SwigPyPacked::size()']]],
  ['size_5fprev_5fleap_5fsec',['size_prev_leap_sec',['../structTAI__UTC.html#a4d269d1b09b5165712688f6e9dc9f8a3',1,'TAI_UTC']]],
  ['slope',['slope',['../structTAI__UTC.html#a42b6c807a393d5efa7d4bf8925536724',1,'TAI_UTC']]],
  ['slots',['slots',['../structPyHeapTypeObject.html#a15212a8f85d939b3f4b133ecda1b62e5',1,'PyHeapTypeObject']]],
  ['soffset',['soffset',['../structPLCairo.html#a6fbef59cc8ca1c6f2cafaffa1d410e71',1,'PLCairo']]],
  ['space',['space',['../structline.html#aef0ac17be02923ca905aefd30661c478',1,'line::space()'],['../structPLStream.html#a4e3572b37ae645577e7ef37debdb550d',1,'PLStream::space()']]],
  ['spdxma',['spdxma',['../structPLStream.html#afed4085b733e54c0ed12daa75a820cd0',1,'PLStream']]],
  ['spdxmi',['spdxmi',['../structPLStream.html#aa23805d34dad648d56f43794d4a5af87',1,'PLStream']]],
  ['spdyma',['spdyma',['../structPLStream.html#af64224dcf1f55df50c24d9cffe8f54aa',1,'PLStream']]],
  ['spdymi',['spdymi',['../structPLStream.html#a4d5687fcb26ffddde55c8c1fe9356f40',1,'PLStream']]],
  ['sppxma',['sppxma',['../structPLStream.html#a99033016e00e950fd6350cd97a75cf91',1,'PLStream']]],
  ['sppxmi',['sppxmi',['../structPLStream.html#a21feedcbe1b56faa0b13a40e689873d9',1,'PLStream']]],
  ['sppyma',['sppyma',['../structPLStream.html#a17c92912eb4f6041148061feeb5223b9',1,'PLStream']]],
  ['sppymi',['sppymi',['../structPLStream.html#a3ca322e16fa00c0ddf52f92c3151eff2',1,'PLStream']]],
  ['squares',['squares',['../structcsa.html#a78cb5b06ce143c384f58999545768398',1,'csa']]],
  ['sscale',['sscale',['../structPLCairo.html#a6abb4af9c6dd1c72562ec2f5c0040780',1,'PLCairo']]],
  ['startlev',['startlev',['../plcont_8c.html#a09bc203f58a3394df2fea3b80cad84e0',1,'plcont.c']]],
  ['state',['state',['../structcdImageStruct.html#ac07a0b2bf544fdd1b7b11c8b6b92d901',1,'cdImageStruct::state()'],['../structplplot_1_1__N2.html#a7a29d46df0fbbe7e8611313517cebf74',1,'plplot::_N2::state()'],['../structplplot__graphics_1_1plgraphicsin.html#ab46cc5f5ffb823805d5379b4834b633b',1,'plplot_graphics::plgraphicsin::state()'],['../structPLGraphicsIn.html#aa49f4f9952d4d5b8ccc36544dc7feebe',1,'PLGraphicsIn::state()']]],
  ['static_5fdevice_5finitializers',['static_device_initializers',['../plcore_8h.html#a7f5f8ba5a9401acf21fd6d5ca1423fd4',1,'plcore.h']]],
  ['stdzoom',['stdzoom',['../namespacePlframe.html#a12eb394109602d2d0826e1af48e3987c',1,'Plframe']]],
  ['str',['str',['../structswig__type__info.html#aaafd19f362ddc521d6a846ce41044471',1,'swig_type_info']]],
  ['stream',['stream',['../classplstream.html#a8842149487ed8a785601f2ecfb66f818',1,'plstream']]],
  ['stream_5fclosed',['stream_closed',['../structPLStream.html#a5509f655765fadb9bd146dd1bd7c0ce3',1,'PLStream']]],
  ['string',['string',['../structplplot_1_1__N2.html#a696d119332c490ebaabfa0b29c1fd1e3',1,'plplot::_N2::string()'],['../structplplot__graphics_1_1plgraphicsin.html#a9766224b44ffda79d464241dcde9e5cd',1,'plplot_graphics::plgraphicsin::string()'],['../structPLGraphicsIn.html#a191b999dad3643a09f6ade464f264a19',1,'PLGraphicsIn::string()'],['../structEscText.html#a980a3c51032d1f0acdc23ea337addf98',1,'EscText::string()']]],
  ['string1',['string1',['../classplplot__str.html#afd1170f9dc3cfa0db09a1fb0a8dc954f',1,'plplot_str']]],
  ['string2',['string2',['../classplplot__str.html#ab01c45a83d8a1bdae24b1633694475a2',1,'plplot_str']]],
  ['string3',['string3',['../classplplot__str.html#a6139dec167df701b79d9a7463e33ddd7',1,'plplot_str']]],
  ['string4',['string4',['../classplplot__str.html#a30a1e262f9732dac2fdd68e2ca64f43f',1,'plplot_str']]],
  ['string5',['string5',['../classplplot__str.html#a1e6037bc03db27b512f9d276371e368f',1,'plplot_str']]],
  ['string6',['string6',['../classplplot__str.html#a85badb92e00f15d1f6c944dcc5990e4b',1,'plplot_str']]],
  ['string7',['string7',['../classplplot__str.html#ae5ae943732297f75b289fe4401c36a20',1,'plplot_str']]],
  ['string8',['string8',['../classplplot__str.html#ac81a1df09a322d47b86b165c42018c6c',1,'plplot_str']]],
  ['string9',['string9',['../classplplot__str.html#a508664498f221e65c6ba381095cfe1e6',1,'plplot_str']]],
  ['string_5flength',['string_length',['../structPLStream.html#abcd74664b14cdd696b689a86a069ee8e',1,'PLStream']]],
  ['strip',['strip',['../plstripc_8c.html#aa9c49c3c484887dc8b161879eabaea1b',1,'plstripc.c']]],
  ['stripc',['stripc',['../plstripc_8c.html#a79aa5be282a61ea370b3bc9d99bfc0d8',1,'plstripc.c']]],
  ['strm',['strm',['../classPlframe_1_1Plframe.html#a3a42ed49d5069a151ee37e1c1b35c802',1,'Plframe::Plframe']]],
  ['style',['style',['../structTextSizeInfo.html#a6a8811179c568c6971b6d242f561b21c',1,'TextSizeInfo']]],
  ['stylelookup',['styleLookup',['../cairo_8c.html#a8ce8f92076a153ae4f1605a83a7bf084',1,'cairo.c']]],
  ['styline',['styline',['../structPLStrip.html#a83a15e04c61fe4cedde35a7c3f01b0ff',1,'PLStrip']]],
  ['sub',['sub',['../structplf2ops__t.html#ac7ea4671d23e8d9e1a11a73e250f4316',1,'plf2ops_t']]],
  ['subclass_5fusage',['subclass_usage',['../plplot__octaveOCTAVE__wrap_8cxx.html#a70e41eebfacedae630ffb0f6830da98d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['subwindow',['subwindow',['../structplplot_1_1__N2.html#a1a62704c90e020de27468d3233dc5e4b',1,'plplot::_N2::subwindow()'],['../structplplot__graphics_1_1plgraphicsin.html#a2f3c4d473f78f69ea05df1804f60a613',1,'plplot_graphics::plgraphicsin::subwindow()'],['../structPLGraphicsIn.html#a87ee773ac5a20f2989f4a4a193750fe4',1,'PLGraphicsIn::subwindow()']]],
  ['surf_5fcont',['SURF_CONT',['../classplplot.html#a3dbcd533882c885f8bdb735f0f014d29',1,'plplot::SURF_CONT()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad4a9643983348bd86607eac153651028',1,'plplot.core.plplotjavacConstants.SURF_CONT()'],['../namespaceplplotc.html#a2a06158f530effb271f9b815c6eb2e81',1,'plplotc.SURF_CONT()']]],
  ['svg_5foptions',['svg_options',['../svg_8c.html#ad78961929f7f8cabbad956cbafdb3f5c',1,'svg.c']]],
  ['svgfile',['svgFile',['../structSVG.html#a9bed1f93609e06dd78b2544a4d6ab53b',1,'SVG']]],
  ['svgindent',['svgIndent',['../structSVG.html#a78278d892660d2756cf0d88e6fa46193',1,'SVG']]],
  ['swig_5fcast_5finitial',['swig_cast_initial',['../plplotluacLUA__wrap_8c.html#a0666e347f7d486a3bc82b78efd732333',1,'swig_cast_initial():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a0666e347f7d486a3bc82b78efd732333',1,'swig_cast_initial():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a0666e347f7d486a3bc82b78efd732333',1,'swig_cast_initial():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['swig_5fcommands',['swig_commands',['../plplotluacLUA__wrap_8c.html#aa647df43a2be38ccba20d3c685d865f4',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fconst_5ftable',['swig_const_table',['../plplotcmodulePYTHON__wrap_8c.html#a6e606ed3240900e595e177ed9012d009',1,'plplotcmodulePYTHON_wrap.c']]],
  ['swig_5fconstants',['swig_constants',['../plplotluacLUA__wrap_8c.html#ad6cf4679bcd945976329a7a2322eb933',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fglobals',['swig_globals',['../plplot__octaveOCTAVE__wrap_8cxx.html#a78ba4a1a89f3ec642716ba1cdbb414b6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fluacode',['SWIG_LUACODE',['../plplotluacLUA__wrap_8c.html#aa51daa176c79b3ddc28ddd7faea49df6',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fmodule',['swig_module',['../plplotluacLUA__wrap_8c.html#a5f41f6e106d3195e660a39e5292f50fd',1,'swig_module():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a5f41f6e106d3195e660a39e5292f50fd',1,'swig_module():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a5f41f6e106d3195e660a39e5292f50fd',1,'swig_module():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['swig_5fname_5fusage',['SWIG_name_usage',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3be459f147c734c484303f9ca2e95fd5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fplgraphicsin_5fattributes',['swig_PLGraphicsIn_attributes',['../plplotluacLUA__wrap_8c.html#a31ea4233864be17d7c1522edd94cae04',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fplgraphicsin_5fbase',['swig_PLGraphicsIn_base',['../plplot__octaveOCTAVE__wrap_8cxx.html#a131d0e3556f9b6d6929bcc035e4decf5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fplgraphicsin_5fbase_5fnames',['swig_PLGraphicsIn_base_names',['../plplotluacLUA__wrap_8c.html#a61ee77e649c977070ca543d7c915c4dd',1,'swig_PLGraphicsIn_base_names():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a61ee77e649c977070ca543d7c915c4dd',1,'swig_PLGraphicsIn_base_names():&#160;plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fplgraphicsin_5fbases',['swig_PLGraphicsIn_bases',['../plplotluacLUA__wrap_8c.html#a628bc42b3766b1f707c39d4744799c70',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fplgraphicsin_5fmembers',['swig_PLGraphicsIn_members',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad3a05f9995d8c5088c40028b1f1dfd7b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fplgraphicsin_5fmethods',['swig_PLGraphicsIn_methods',['../plplotluacLUA__wrap_8c.html#ae99b2700e57e59871b8f487565d83c73',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fthis',['swig_this',['../plplotcmodulePYTHON__wrap_8c.html#aa46bee1d6fc5b229095ab118d8925636',1,'plplotcmodulePYTHON_wrap.c']]],
  ['swig_5fthis_5fusage',['swig_this_usage',['../plplot__octaveOCTAVE__wrap_8cxx.html#ade4b7dfe74b1deb042e21c0cb9335f84',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5ftype_5finitial',['swig_type_initial',['../plplotluacLUA__wrap_8c.html#ad621c8a05a43cf3a48467c791142bb44',1,'swig_type_initial():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ad621c8a05a43cf3a48467c791142bb44',1,'swig_type_initial():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ad621c8a05a43cf3a48467c791142bb44',1,'swig_type_initial():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['swig_5ftype_5fusage',['swig_type_usage',['../plplot__octaveOCTAVE__wrap_8cxx.html#a74bda2c13e54a9066ddaef85f389a5a8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5ftypequery_5fusage',['swig_typequery_usage',['../plplot__octaveOCTAVE__wrap_8cxx.html#a334ee93af44aca1d08e52dee7590938d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5ftypes',['swig_types',['../plplotluacLUA__wrap_8c.html#a5a4358414fc0b190c3d0255e2d5d4ca2',1,'swig_types():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a0f20ac04d873220b9386f47abb3b6981',1,'swig_types():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#af4809c9a7db4f3441c30d3f462a52de0',1,'swig_types():&#160;plplotcmodulePYTHON_wrap.c']]],
  ['swig_5fvariables',['swig_variables',['../plplotluacLUA__wrap_8c.html#af3bb62e270edaa3cc9bfcff5e8a6b143',1,'plplotluacLUA_wrap.c']]],
  ['swigcmemown',['swigCMemOwn',['../classplplot_1_1core_1_1PLGraphicsIn.html#a8cb8b0490aaa35e053fefad989f5593f',1,'plplot::core::PLGraphicsIn']]],
  ['swigcptr',['swigCPtr',['../classplplot_1_1core_1_1PLGraphicsIn.html#a91a8f0db89c6b1512d0c2e33899c09e7',1,'plplot::core::PLGraphicsIn']]],
  ['swigmethods',['SwigMethods',['../plplotcmodulePYTHON__wrap_8c.html#aa03a15903621be80f4e3b2017e74d115',1,'plplotcmodulePYTHON_wrap.c']]],
  ['swigobject_5fmethods',['swigobject_methods',['../plplotcmodulePYTHON__wrap_8c.html#a4e964af1d130dbfe312a46f36c39e2b8',1,'plplotcmodulePYTHON_wrap.c']]],
  ['sx',['sx',['../structcdImageStruct.html#ae159bf45e88595fa2ac6650fd85ec6e1',1,'cdImageStruct']]],
  ['sy',['sy',['../structcdImageStruct.html#a06ddf25d32c2c3312d7ea2dc1699dd61',1,'cdImageStruct']]],
  ['symbol',['symbol',['../structEscText.html#aa023e7837b12c8dcc568554a84c8e62c',1,'EscText']]],
  ['symbol_5fbuffer',['symbol_buffer',['../plsym_8c.html#a410471b0b6596b7ad70060d6ce18b159',1,'plsym.c']]],
  ['symdef',['symdef',['../structPLStream.html#a26607874d1df464949886828776bda07',1,'PLStream']]],
  ['symht',['symht',['../structPLStream.html#a0d3c7b02bf7917634766b37f5745a748',1,'PLStream']]],
  ['synchronize',['synchronize',['../tkMain_8c.html#a7becec33199366ac358f4a7a039735e6',1,'tkMain.c']]],
  ['syntax',['syntax',['../structplplot_1_1__N1.html#aeb5532a5b0d093f0d550a4bb30b04558',1,'plplot::_N1::syntax()'],['../structPLOptionTable.html#a8d7b4d190a1e071a20a20e7ba022e700',1,'PLOptionTable::syntax()']]]
];
